@@ -13,11 +13,13 @@ import time
 from typing import Dict, List, Optional
 
 import attr
+import httpx
 
 from .decorators import run_async_synchronously
 from .foundation import DenonAVRFoundation, set_api_host, set_api_timeout
 from .const import (
     DENON_ATTR_SETATTR, MAIN_ZONE, VALID_ZONES)
+from .exceptions import AvrCommandError
 
 from .audyssey import DenonAVRAudyssey, audyssey_factory
 from .input import DenonAVRInput, input_factory
@@ -185,6 +187,14 @@ class DenonAVR(DenonAVRFoundation):
         Method executes the update method for the current receiver type.
         """
 
+    async def async_update_tonecontrol(self):
+        """Get Tonecontrol settings."""
+        await self.tonecontrol.async_update()
+
+    @run_async_synchronously(async_func=async_update_tonecontrol)
+    def update_tonecontrol(self):
+        """Get Tonecontrol settings."""
+
     async def async_update_audyssey(self):
         """Get Audyssey settings."""
         await self.audyssey.async_update()
@@ -456,6 +466,17 @@ class DenonAVR(DenonAVRFoundation):
     ##########
     # Setter #
     ##########
+    def set_async_client(self, async_client: httpx.AsyncClient) -> None:
+        """
+        Set a custom httpx.AsyncClient for this instance.
+
+        This is a non-blocking method.
+        """
+        if not issubclass(async_client, httpx.AsyncClient):
+            raise AvrCommandError(
+                "Provided client is not a subclass of httpx.AsyncClient")
+        self._device.api.async_client = async_client
+
     @run_async_synchronously(async_func=async_dynamic_eq_off)
     def dynamic_eq_off(self) -> None:
         """Turn DynamicEQ off."""
@@ -501,7 +522,7 @@ class DenonAVR(DenonAVRFoundation):
         Valid values depend on the device and should be taken from
         "sound_mode_list".
         """
-        await self.soundmode.async_set_sound_mode()
+        await self.soundmode.async_set_sound_mode(sound_mode)
 
     @run_async_synchronously(async_func=async_set_sound_mode)
     def set_sound_mode(self, sound_mode: str) -> None:
@@ -648,6 +669,42 @@ class DenonAVR(DenonAVRFoundation):
         Doesn't work, if Dynamic Equalizer is active.
         """
 
+    async def async_bass_up(self) -> None:
+        """
+        Increase level of Bass.
+
+        Note:
+        Doesn't work, if Dynamic Equalizer is active
+        """
+        await self.tonecontrol.async_bass_up()
+
+    @run_async_synchronously(async_func=async_bass_up)
+    def bass_up(self) -> None:
+        """
+        Increase level of Bass.
+
+        Note:
+        Doesn't work, if Dynamic Equalizer is active
+        """
+
+    async def async_bass_down(self) -> None:
+        """
+        Decrease level of Bass.
+
+        Note:
+        Doesn't work, if Dynamic Equalizer is active
+        """
+        await self.tonecontrol.async_bass_down()
+
+    @run_async_synchronously(async_func=async_bass_down)
+    def bass_down(self) -> None:
+        """
+        Decrease level of Bass.
+
+        Note:
+        Doesn't work, if Dynamic Equalizer is active
+        """
+
     async def async_set_treble(self, value: int) -> None:
         """
         Set receiver treble.
@@ -669,3 +726,39 @@ class DenonAVR(DenonAVRFoundation):
         Note:
         Doesn't work, if Dynamic Equalizer is active.
         """
+
+    async def async_treble_up(self) -> None:
+        """
+        Increase level of Treble.
+
+        Note:
+        Doesn't work, if Dynamic Equalizer is active
+        """
+        await self.tonecontrol.async_treble_up()
+
+    @run_async_synchronously(async_func=async_treble_up)
+    def treble_up(self) -> None:
+        """
+        Increase level of Treble.
+
+        Note:
+        Doesn't work, if Dynamic Equalizer is active
+        """
+
+    async def async_treble_down(self) -> None:
+        """
+        Decrease level of Treble.
+
+        Note:
+        Doesn't work, if Dynamic Equalizer is active
+        """
+        await self.tonecontrol.async_treble_down()
+
+    @run_async_synchronously(async_func=async_treble_down)
+    def treble_down(self) -> None:
+        """
+        Decrease level of Treble.
+
+        Note:
+        Doesn't work, if Dynamic Equalizer is active
+        """
