@@ -593,7 +593,7 @@ class DenonAVRInput(DenonAVRFoundation):
         # Test if image URL is accessable
         if self._image_available is None and self._image_url is not None:
             try:
-                async with httpx.AsyncClient() as client:
+                async with self._device.api.async_client() as client:
                     res = await client.get(
                         self._image_url, timeout=self._device.api.timeout)
                     res.raise_for_status()
@@ -737,7 +737,7 @@ class DenonAVRInput(DenonAVRFoundation):
         if (self._state == STATE_PLAYING and
                 self._input_func in self._netaudio_func_list):
             await self.async_pause()
-        if self._input_func in self._netaudio_func_list:
+        elif self._input_func in self._netaudio_func_list:
             await self.async_play()
 
     async def async_play(self) -> None:
